@@ -14,15 +14,26 @@ quakemod1=summary(lm(log10(accel)~mag+log10(dist),data=attenu))
 
 XLregresSummary(book4,"ModelScale",varnames=quakenames,
                 betas=quakemod1$coef[-1,1],SE=quakemod1$coef[-1,2],
-                pround=6,title="Log-Ground Acceleration Effects",
+                ,title="Log-Ground Acceleration Effects",
                 confac=qt(0.975,179),pfun=function(x) 2*pt(-abs(x),df=179))
 
-## Effects arguably more meaningful as percent change. So still same model, but different summaries:
+## Same thing, but using matrix input; no need to provide SE and names. 
+## It is arguably still nicer to provide your own names - but could be a reproducibility risk. 
+## Also, increasing the p-value resolution by changing 'pround'.
 
-XLregresSummary(book4,"Multiplier",varnames=quakenames,
-                betas=quakemod1$coef[-1,1],SE=quakemod1$coef[-1,2],
-                pround=6,title="Relative Ground Acceleration Effects",transfun=function(x) 10^x,
-                effname="Multiplier",confac=qt(0.975,179),pfun=function(x) 2*pt(-abs(x),df=179))
+XLregresSummary(book4,"ModelScale",betas=quakemod1$coef[-1,],
+                pround=6,title="Log-Ground Acceleration Effects",
+                confac=qt(0.975,179),pfun=function(x) 2*pt(-abs(x),df=179),row1=8)
+
+## Effects are arguably more meaningful as percent change. 
+## So... still same model, but different summaries. 
+## Also, note the combination of matrix input with names over-written via 'varnames':
+
+XLregresSummary(book4,"PercentChange",varnames=quakenames,
+                betas=quakemod1$coef[-1,],
+                roundig=1,pround=6,title="Relative Ground Acceleration Effects",
+                transfun=function(x) 100*(10^x-1),
+                effname="Percent Change",confac=qt(0.975,179),pfun=function(x) 2*pt(-abs(x),df=179))
 
 cat("Look for",paste(getwd(),"attenu.xls",sep='/'),"to see the results!\n")
 
@@ -35,7 +46,8 @@ cat("Look for",paste(getwd(),"attenu.xls",sep='/'),"to see the results!\n")
 # 
 # XLregresSummary(book4,"MixedModel",varnames=quakenames,betas=fixef(quakemod2)[-1],
 # SE=sqrt(diag(vcov(quakemod2)))[-1],
-# pround=6,title="Relative Ground Acceleration Effects",
-# transfun=function(x) 10^x,effname="Multiplier",
+# roundig=1,pround=6,
+# title="Relative Ground Acceleration Effects",
+# transfun=function(x) 100*(10^x-1),effname="Percent Change",
 # confac=qt(0.975,160),pfun=function(x) 2*pt(-abs(x),df=160))
 
